pub enum ClearCacheError {
Internal,
Throttle,
Unknown(es_clear_cache_result_t),
ApiUnavailable,
}Available on macOS only.
Clearing authorisation caches failed.
Usually constructed using
es_clear_cache_result_t::ok().
Variants
Internal
Throttle
Unknown(es_clear_cache_result_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)