Enum endpoint_sec_sys::NewClientError
source · pub enum NewClientError {
InvalidArgument,
Internal,
NotEntitled,
NotPermitted,
NotPrivileged,
TooManyClients,
Unknown(es_new_client_result_t),
ApiUnavailable,
}Available on macOS only.
Creating a new client failed.
Usually constructed using
es_new_client_result_t::ok().
Variants
InvalidArgument
Internal
NotEntitled
NotPermitted
NotPrivileged
TooManyClients
Available on crate feature
macos_10_15_1 only.Unknown(es_new_client_result_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)