pub enum OpensshLoginError {
LoginExceedMaxTries,
LoginRootDenied,
AuthNone,
AuthPassword,
AuthKbdint,
AuthPubkey,
AuthHostBased,
AuthGssapi,
InvalidUser,
Unknown(es_openssh_login_result_type_t),
ApiUnavailable,
}Available on macOS only.
OpenSSH login failed.
Usually constructed using
es_openssh_login_result_type_t::ok().
Variants
LoginExceedMaxTries
LoginRootDenied
AuthNone
AuthPassword
AuthKbdint
AuthPubkey
AuthHostBased
AuthGssapi
InvalidUser
Unknown(es_openssh_login_result_type_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)