Enum endpoint_sec_sys::RespondError
source · pub enum RespondError {
InvalidArgument,
Internal,
MessageNotFound,
DuplicateResponse,
EventType,
Unknown(es_respond_result_t),
ApiUnavailable,
}Available on macOS only.
Responding to a message failed.
Usually constructed using
es_respond_result_t::ok().
Variants
InvalidArgument
Internal
MessageNotFound
DuplicateResponse
EventType
Unknown(es_respond_result_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)