Enum endpoint_sec_sys::ReturnError
source · pub enum ReturnError {
Error,
Unknown(es_return_t),
ApiUnavailable,
}Available on macOS only.
Basic error without additional informations.
Usually constructed using
es_return_t::ok().
Variants
Error
See ES_RETURN_ERROR
Unknown(es_return_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)