pub struct ShouldNotBeNull<T: ?Sized>(/* private fields */);Available on macOS only.
A wrapper type around *mut T to communicate a pointer should not be null without introducing
undefined behaviour.
This is necessary for FFI, where, NonNull asks for much stronger
guarantees, which we can’t really provide when getting pointers from behind a C interface.
ShouldNotBeNull aims for the same usability as NonNull but with panics instead of undefined
behaviour when calling methods like as_ref().
Construction is done either directly from C since ShouldNotBeNull is a transparent wrapper or
with ShouldNotBeNull::new.
Implementations