#[repr(C)]
pub struct audit_token_t { pub val: [c_uint; 8], }
Available on macOS only.
The audit token is an opaque token which identifies Mach tasks and senders of Mach messages as subjects to the BSM audit system. Only the appropriate BSM library routines should be used to interpret the contents of the audit token as the representation of the subject identity within the token may change over time.

Starting with macOS 11, almost all audit functions have been deprecated (see the system header bsm/libbsm.h), do not use them if your program target more recent versions of macOS.

Fields

val: [c_uint; 8]

Value of the token

This is considered an opaque value, do not rely on its format