#[repr(transparent)]pub struct es_auth_result_t(pub u32);Available on macOS only.
Valid authorization values to be used when responding to a
es_message_t auth event
Tuple Fields
0: u32Implementations
Sourceimpl es_auth_result_t
Variants available from macOS 10.15.0 onwards
impl es_auth_result_t
Variants available from macOS 10.15.0 onwards
Sourcepub const ES_AUTH_RESULT_ALLOW: es_auth_result_t
pub const ES_AUTH_RESULT_ALLOW: es_auth_result_t
The event is authorized and should be allowed to continue
Sourcepub const ES_AUTH_RESULT_DENY: es_auth_result_t
pub const ES_AUTH_RESULT_DENY: es_auth_result_t
The event is not authorized and should be blocked
Last value for macOS 10.15.0