#[repr(transparent)]pub struct es_authorization_rule_class_t(pub u32);Available on macOS only.
The class of rules used to evaluate the petition for a specific authorization right
Tuple Fields
0: u32Implementations
Variants available from macOS 14.0.0 onwards
sourcepub const ES_AUTHORIZATION_RULE_CLASS_USER: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_USER: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is judged on user properties
sourcepub const ES_AUTHORIZATION_RULE_CLASS_RULE: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_RULE: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is judged by a tree of sub-rules
sourcepub const ES_AUTHORIZATION_RULE_CLASS_MECHANISM: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_MECHANISM: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is judged by one or more plugins
sourcepub const ES_AUTHORIZATION_RULE_CLASS_ALLOW: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_ALLOW: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is always granted
sourcepub const ES_AUTHORIZATION_RULE_CLASS_DENY: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_DENY: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is always denied
sourcepub const ES_AUTHORIZATION_RULE_CLASS_UNKNOWN: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_UNKNOWN: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is unknown
sourcepub const ES_AUTHORIZATION_RULE_CLASS_INVALID: es_authorization_rule_class_t = _
Available on crate feature macos_14_0_0 only.
pub const ES_AUTHORIZATION_RULE_CLASS_INVALID: es_authorization_rule_class_t = _
macos_14_0_0 only.Right is invalid
Last value for macOS 14.0.0
sourcepub const LAST_14_0_0: es_authorization_rule_class_t = es_authorization_rule_class_t::ES_AUTHORIZATION_RULE_CLASS_INVALID
Available on crate feature macos_14_0_0 only.
pub const LAST_14_0_0: es_authorization_rule_class_t = es_authorization_rule_class_t::ES_AUTHORIZATION_RULE_CLASS_INVALID
macos_14_0_0 only.Easily identifiable name for the last member of macOS 14.0.0