Struct endpoint_sec_sys::es_event_clone_t
source · #[repr(C)]pub struct es_event_clone_t {
pub source: ShouldNotBeNull<es_file_t>,
pub target_dir: ShouldNotBeNull<es_file_t>,
pub target_name: es_string_token_t,
/* private fields */
}Available on macOS and crate feature
macos_10_15_1 only.Expand description
Clone a file
This event type does not support caching.
Fields
source: ShouldNotBeNull<es_file_t>The file that will be cloned
target_dir: ShouldNotBeNull<es_file_t>The directory into which the source file will be cloned
target_name: es_string_token_tThe name of the new file to which source will be cloned
Implementations
sourceimpl es_event_clone_t
impl es_event_clone_t
Accessors for ShouldNotBeNull fields
sourcepub unsafe fn source(&self) -> &es_file_t
pub unsafe fn source(&self) -> &es_file_t
Gives a references to the field while checking for null.
Safety
See ShouldNotBeNull safety requirements.
sourcepub unsafe fn target_dir(&self) -> &es_file_t
pub unsafe fn target_dir(&self) -> &es_file_t
Gives a references to the field while checking for null.
Safety
See ShouldNotBeNull safety requirements.