#[repr(C)]pub struct es_event_od_attribute_value_remove_t {
pub instigator: *mut es_process_t,
pub error_code: i32,
pub record_type: es_od_record_type_t,
pub record_name: es_string_token_t,
pub attribute_name: es_string_token_t,
pub attribute_value: es_string_token_t,
pub node_name: es_string_token_t,
pub db_path: es_string_token_t,
pub instigator_token: audit_token_t,
}macos_14_0_0 only.Expand description
Notification that an attribute value was removed to a record.
This event type does not support caching (notify-only).
Attributes conceptually have the type Map String (Set String).
Each OD record has a Map of attribute name to Set of attribute value.
When an attribute value is removed, it is inserted into the set of values for that name.
Removing a value that was never added is a no-op.
Fields
instigator: *mut es_process_tProcess that instigated operation (XPC caller).
error_code: i32Result code for the operation.
Values indicating specific failure reasons are defined in odconstants.h.
record_type: es_od_record_type_tThe type of the record to which the attribute value was removed.
record_name: es_string_token_tThe name of the record to which the attribute value was removed.
attribute_name: es_string_token_tThe name of the attribute to which the value was removed.
attribute_value: es_string_token_tThe value that was removed.
node_name: es_string_token_tOD node being mutated.
Typically one of “/Local/Default”, “/LDAPv3/
db_path: es_string_token_tOptional. If node_name is “/Local/Default”, this is, the path of the database against which OD is authenticating.
instigator_token: audit_token_tmacos_15_0_0 only.Audit token of the process that instigated this event.
Field available only if message version >= 8.
Implementations
Sourceimpl es_event_od_attribute_value_remove_t
Accessors for *mut and *const fields
impl es_event_od_attribute_value_remove_t
Accessors for *mut and *const fields
Sourcepub unsafe fn instigator(&self) -> Option<&es_process_t>
pub unsafe fn instigator(&self) -> Option<&es_process_t>
Helper to avoid the is_null() + deref every time.
Safety
The pointer must be valid (aligned & initialized) for a value of the expected type.