#[repr(C)]
pub struct es_event_settime_t { /* private fields */ }
Available on macOS only.
Modify the system time

This event is not fired if the program contains the entitlement com.apple.private.settime. Additionally, even if an ES client responds to ES_EVENT_TYPE_AUTH_SETTIME events with ES_AUTH_RESULT_ALLOW, the operation may still fail for other reasons (e.g. unprivileged user).

This event type does not support caching.