es_event_tcc_modify_t

Struct es_event_tcc_modify_t 

#[repr(C)]
pub struct es_event_tcc_modify_t { pub service: es_string_token_t, pub identity: es_string_token_t, pub identity_type: es_tcc_identity_type_t, pub update_type: es_tcc_event_type_t, pub instigator_token: audit_token_t, pub instigator: *mut es_process_t, pub responsible_token: *mut audit_token_t, pub responsible: *mut es_process_t, pub right: es_tcc_authorization_right_t, pub reason: es_tcc_authorization_reason_t, }
Available on macOS and crate feature macos_15_4_0 only.
TCC Modification Event.

Occurs when a TCC permission is granted or revoked.

Note: This event type does not support caching.

Fields

service: es_string_token_t

The TCC service for which permissions are being modified.

identity: es_string_token_t

The identity of the application that is the subject of the permission.

identity_type: es_tcc_identity_type_t

The identity type of the application string (Bundle ID, path, etc).

update_type: es_tcc_event_type_t

The type of TCC modification event (Grant/Revoke etc)

instigator_token: audit_token_t

Audit token of the instigator of the modification.

instigator: *mut es_process_t

(Optional) The process information for the instigator.

responsible_token: *mut audit_token_t

(Optional) Audit token of the responsible process for the modification.

responsible: *mut es_process_t

(Optional) The process information for the responsible process.

right: es_tcc_authorization_right_t

The resulting TCC permission of the operation/modification.

reason: es_tcc_authorization_reason_t

The reason the TCC permissions were updated.

Implementations

Source

impl es_event_tcc_modify_t

Accessors for *mut and *const fields

pub unsafe fn instigator(&self) -> Option<&es_process_t>

Helper to avoid the is_null() + deref every time.

Safety

The pointer must be valid (aligned & initialized) for a value of the expected type.

pub unsafe fn responsible_token(&self) -> Option<&audit_token_t>

Helper to avoid the is_null() + deref every time.

Safety

The pointer must be valid (aligned & initialized) for a value of the expected type.

pub unsafe fn responsible(&self) -> Option<&es_process_t>

Helper to avoid the is_null() + deref every time.

Safety

The pointer must be valid (aligned & initialized) for a value of the expected type.