Struct endpoint_sec_sys::es_event_trace_t
source · #[repr(C)]pub struct es_event_trace_t {
pub target: ShouldNotBeNull<es_process_t>,
/* private fields */
}Available on macOS only.
Fired when one process attempts to attach to another process
This event can fire multiple times for a single trace attempt, for example when the processes to which is being attached is reparented during the operation
This event type does not support caching (notify-only).
Fields
target: ShouldNotBeNull<es_process_t>The process that will be attached to by the process that instigated the event
Implementations
sourceimpl es_event_trace_t
impl es_event_trace_t
Accessors for ShouldNotBeNull fields
sourcepub unsafe fn target(&self) -> &es_process_t
pub unsafe fn target(&self) -> &es_process_t
Gives a references to the field while checking for null.
Safety
See ShouldNotBeNull safety requirements.