Struct endpoint_sec_sys::es_return_t
source · #[repr(transparent)]pub struct es_return_t(pub u32);Available on macOS only.
Return value for functions that can only fail in one way
Tuple Fields
0: u32Implementations
sourceimpl es_return_t
impl es_return_t
Variants available from macOS 10.15.0 onwards
sourcepub const ES_RETURN_SUCCESS: es_return_t = _
pub const ES_RETURN_SUCCESS: es_return_t = _
Function was successful
sourcepub const ES_RETURN_ERROR: es_return_t = _
pub const ES_RETURN_ERROR: es_return_t = _
Function failed
Last value for macOS 10.15.0
sourcepub const LAST_10_15_0: es_return_t = es_return_t::ES_RETURN_ERROR
pub const LAST_10_15_0: es_return_t = es_return_t::ES_RETURN_ERROR
Easily identifiable name for the last member of macOS 10.15.0
sourceimpl es_return_t
impl es_return_t
sourcepub fn ok(self) -> Result<(), ReturnError>
pub fn ok(self) -> Result<(), ReturnError>
Converts an instance of es_return_t to a Result<(), ReturnError>