Enum endpoint_sec_sys::MuteTypeError
source · pub enum MuteTypeError {
Error,
Unknown(es_mute_inverted_return_t),
ApiUnavailable,
}Available on macOS and crate feature
macos_13_0_0 only.Expand description
Getting the mute type failed.
Usually constructed using es_mute_inverted_return_t::ok()
Variants
Error
Unknown(es_mute_inverted_return_t)
Catches new variants in the C enum
Used to signal a call to an unavailable API, either because it was removed or because it is only available in higher versions (eg 12.0+ when running on macOS 11.0)