pub struct ShouldNotBeNull<T: ?Sized>(/* private fields */);
Available on macOS only.
A wrapper type around *mut T to communicate a pointer should not be null without introducing undefined behaviour.

This is necessary for FFI, where, NonNull asks for much stronger guarantees, which we can’t really provide when getting pointers from behind a C interface. ShouldNotBeNull aims for the same usability as NonNull but with panics instead of undefined behaviour when calling methods like as_ref().

Construction is done either directly from C since ShouldNotBeNull is a transparent wrapper or with ShouldNotBeNull::new.

Implementations

source

impl<T: ?Sized> ShouldNotBeNull<T>

source

pub fn new(p: *mut T) -> Self

Wraps p in a ShouldNotBeNull.

source

pub unsafe fn as_ref<'a>(&self) -> &'a T

Calls as_ref() on the inner pointer, panicking if it is null.

Safety

See ptr::as_ref() for the exact safety details.

source

pub unsafe fn as_opt<'a>(&self) -> Option<&'a T>

Calls as_ref() on the inner pointer.

Safety

See ptr::as_ref() for the exact safety details.

source

pub const fn as_ptr(self) -> *const T

Access to the inner pointer as a *const