Struct endpoint_sec_sys::es_auth_result_t
source · #[repr(transparent)]pub struct es_auth_result_t(pub u32);Available on macOS only.
Valid authorization values to be used when responding to a
es_message_t auth event
Tuple Fields
0: u32Implementations
sourceimpl es_auth_result_t
impl es_auth_result_t
Variants available from macOS 10.15.0 onwards
sourcepub const ES_AUTH_RESULT_ALLOW: es_auth_result_t = _
pub const ES_AUTH_RESULT_ALLOW: es_auth_result_t = _
The event is authorized and should be allowed to continue
sourcepub const ES_AUTH_RESULT_DENY: es_auth_result_t = _
pub const ES_AUTH_RESULT_DENY: es_auth_result_t = _
The event is not authorized and should be blocked
Last value for macOS 10.15.0
sourcepub const LAST_10_15_0: es_auth_result_t = es_auth_result_t::ES_AUTH_RESULT_DENY
pub const LAST_10_15_0: es_auth_result_t = es_auth_result_t::ES_AUTH_RESULT_DENY
Easily identifiable name for the last member of macOS 10.15.0