#[repr(C)]pub struct es_signed_file_info_t {
pub cdhash: es_cdhash_t,
pub signing_id: es_string_token_t,
pub team_id: es_string_token_t,
}Available on macOS and crate feature
macos_15_0_0 only.Expand description
Information from a signed file.
If the file is a multiarchitecture binary, only the information for the native host architecture is reported. I.e. the CDHash from the AArch64 slice if the host is AArch64.
Fields
cdhash: es_cdhash_tCode Directory Hash
signing_id: es_string_token_tSigning Identifier, if available in the signing information.
team_id: es_string_token_tTeam Identifier, if available in the signing information.